[GRASS-SVN] r65180 - in grass/trunk: lib/init mswindows mswindows/osgeo4w scripts/g.manual

svn_grass at osgeo.org svn_grass at osgeo.org
Sun May 3 04:24:33 PDT 2015


Author: martinl
Date: 2015-05-03 04:24:32 -0700 (Sun, 03 May 2015)
New Revision: 65180

Modified:
   grass/trunk/lib/init/grass.py
   grass/trunk/mswindows/env.bat
   grass/trunk/mswindows/osgeo4w/env.bat.tmpl
   grass/trunk/scripts/g.manual/g.manual.py
Log:
attempt to fix g.manual on Windows (see also r65179)


Modified: grass/trunk/lib/init/grass.py
===================================================================
--- grass/trunk/lib/init/grass.py	2015-05-03 11:16:40 UTC (rev 65179)
+++ grass/trunk/lib/init/grass.py	2015-05-03 11:24:32 UTC (rev 65180)
@@ -478,8 +478,9 @@
             browser = gfile('etc', "html_browser_mac.sh")
             os.environ['GRASS_HTML_BROWSER_MACOSX'] = "-b com.apple.helpviewer"
 
-        if windows or cygwin:
-            # MinGW startup moved to into init.bat
+        if windows:
+            browser = "start"
+        elif cygwin:
             browser = "explorer"
         else:
             # the usual suspects

Modified: grass/trunk/mswindows/env.bat
===================================================================
--- grass/trunk/mswindows/env.bat	2015-05-03 11:16:40 UTC (rev 65179)
+++ grass/trunk/mswindows/env.bat	2015-05-03 11:24:32 UTC (rev 65180)
@@ -6,8 +6,6 @@
 REM To enable bash prompt please uncomment the line bellow
 REM set GRASS_SH=%GISBASE%\msys\bin\sh.exe
 
-set GRASS_HTML_BROWSER=explorer
-
 set GRASS_PYTHON=%GISBASE%\extrabin\python.exe
 set PYTHONHOME=%GISBASE%\Python27
 

Modified: grass/trunk/mswindows/osgeo4w/env.bat.tmpl
===================================================================
--- grass/trunk/mswindows/osgeo4w/env.bat.tmpl	2015-05-03 11:16:40 UTC (rev 65179)
+++ grass/trunk/mswindows/osgeo4w/env.bat.tmpl	2015-05-03 11:24:32 UTC (rev 65180)
@@ -7,8 +7,6 @@
 REM To enable bash prompt please uncomment the line bellow
 REM set GRASS_SH=%OSGEO4W_ROOT%\apps\msys\bin\sh.exe
 
-set GRASS_HTML_BROWSER=explorer
-
 set GRASS_PYTHON=%OSGEO4W_ROOT%\bin\python.exe
 set PYTHONHOME=%OSGEO4W_ROOT%\apps\Python27
 

Modified: grass/trunk/scripts/g.manual/g.manual.py
===================================================================
--- grass/trunk/scripts/g.manual/g.manual.py	2015-05-03 11:16:40 UTC (rev 65179)
+++ grass/trunk/scripts/g.manual/g.manual.py	2015-05-03 11:24:32 UTC (rev 65180)
@@ -56,7 +56,7 @@
 
 def start_browser(entry):
     if browser and \
        browser not in ('xdg-open', 'explorer') and \
        not grass.find_program(browser):
         grass.fatal(_("Browser '%s' not found") % browser)
 
@@ -75,7 +75,7 @@
     
         url_path = 'file://' + path
     
-    if browser:
+    if browser and browser not in ('xdg-open', 'start'):
         webbrowser.register(browser_name, None)
     
     grass.verbose(_("Starting browser '%(browser)s' for manual"
@@ -56,7 +56,7 @@
 def start_browser(entry):
     if browser and \
-       browser not in ('xdg-open', 'explorer') and \
+       browser not in ('xdg-open', 'start') and \
        not grass.find_program(browser):
         grass.fatal(_("Browser '%s' not found") % browser)



More information about the grass-commit mailing list